
.. _user_guide:

==========
User Guide
==========

Welcome to aeon's user guide!

The user guide consists of introductory notebooks, ordered by learning task.

For guided tutorials with videos, see our :ref:`tutorials` page.

To run the user guide notebooks interactively, you can
`launch them on binder <https://mybinder.org/v2/gh/aeon-toolkit/aeon/main?filepath=examples>`_
without having to install anything.

We assume basic familiarity with `scikit-learn`_. If you haven’t worked with scikit-learn before, check out their
`getting-started guide`_.

The notebook files can be found `here <https://github.com/aeon-toolkit/aeon/blob/main/examples>`_.

.. _scikit-learn: https://scikit-learn.org/stable/
.. _getting-started guide: https://scikit-learn.org/stable/getting_started.html

.. nbgallery::
    :glob:

    examples/*
